@@ -8,16 +8,18 @@
 #       extension: .py
 #       format_name: light
 #       format_version: '1.5'
-#       jupytext_version: 1.14.4
+#       jupytext_version: 1.14.0
 #   kernelspec:
-#     display_name: Python 3 (ipykernel)
+#     display_name: Python 3.9 (XPython)
 #     language: python
-#     name: python3
+#     name: xpython
 # ---
 
 # +
 """General widget for editing data"""
+# %run _dev_sys_path_append.py
 # %run __init__.py
+#
 # %run ../__init__.py
 # %load_ext lab_black
 # TODO: move editgrid.py to root
@@ -41,6 +43,7 @@ MAP_TRANSPOSED_SELECTION_MODE = frozenmap({True: "column", False: "row"})
 # TODO: rename "add" to "fn_add" so not ambiguous...
 # -
 
+
 class DataHandler(BaseModel):
     """CRUD operations for a for EditGrid.
     Can be used to connect to a database or other data source.
@@ -308,11 +311,11 @@ class EditGrid(w.VBox):
 
         self._init_form()
         if ui_add is None:
-            self.ui_add = AutoObjectFiltered(self.row_schema, app=self)
+            self.ui_add = aui.AutoObject(self.row_schema, app=self)
         else:
             self.ui_add = ui_add(self.row_schema, app=self)
         if ui_edit is None:
-            self.ui_edit = AutoObjectFiltered(self.row_schema, app=self)
+            self.ui_edit = aui.AutoObject(self.row_schema, app=self)
         else:
             self.ui_edit = ui_edit(self.row_schema, app=self)
         if ui_delete is None:
@@ -381,6 +384,14 @@ class EditGrid(w.VBox):
         self.grid.observe(self._observe_selections, "selections")
         self.grid.observe(self._grid_changed, "count_changes")
         self.buttonbar_grid.observe(self._setview, "active")
+        self.grid.observe(self._observe_order, "order")
+        self._observe_order(None)  # prompts order if it is set in by grid setter above
+
+    def _observe_order(self, on_change):
+        if "order" in self.ui_add.traits() and self.grid.order is not None:
+            self.ui_add.order = self.grid.order
+        if "order" in self.ui_edit.traits() and self.grid.order is not None:
+            self.ui_edit.order = self.grid.order
 
     def _observe_selections(self, onchange):
         if self.buttonbar_grid.edit.value:
@@ -577,55 +588,6 @@ class EditGrid(w.VBox):
             traceback.print_exc()
 
 
-class AutoObjectFiltered(aui.AutoObject):
-    """This extended AutoObject class relies on EditGrid and a row_schema dictionary.
-
-    The AutoObject will update its rows based on the visible rows of the grid.
-    """
-
-    def __init__(self, row_schema: dict, app: EditGrid, *args, **kwargs):
-        self.app = app
-        self._selections = []
-        super().__init__(row_schema, *args, **kwargs)
-        if self.app is not None:
-            self.app.grid.observe(self._update_order, "_visible_rows")
-            self.app.grid.observe(
-                self._save_previous_selections, "selections"
-            )  # Re-apply selection after updating transforms
-
-    def _get_visible_fields(self):
-        """Get the list of fields that are visible in the DataGrid."""
-        if isinstance(self.app.grid.get_visible_data().index, pd.MultiIndex) is True:
-            title_idx = self.app.grid.get_visible_data().index.names.index("title")
-            visible_titles = [
-                v[title_idx] for v in self.app.grid.get_visible_data().index
-            ]
-            return [
-                k
-                for k, v in self.app.row_schema["properties"].items()
-                if v["title"] in visible_titles
-            ]
-        elif isinstance(self.app.grid.get_visible_data().index, pd.Index) is True:
-            return [
-                k
-                for k, v in self.app.row_schema["properties"].items()
-                if v["title"] in self.app.grid.get_visible_data().index
-            ]
-
-        else:
-            raise Exception("Index obtained not of correct type.")
-
-    def _update_order(self, onchange):
-        """Update order instance of AutoObject based on visible fields in the DataGrid."""
-        if self.app.transposed is True:
-            self.order = self._get_visible_fields()
-            self.app.grid.selections = self._selections
-
-    def _save_previous_selections(self, onchange):
-        if self.app.grid.selections:
-            self._selections = self.app.grid.selections
-
-
 if __name__ == "__main__":
     # Test: EditGrid instance with multi-indexing.
     AUTO_GRID_DEFAULT_VALUE = [
@@ -640,7 +602,9 @@ if __name__ == "__main__":
     class DataFrameCols(BaseModel):
         string: str = Field("string", column_width=100, section="a")
         integer: int = Field(1, column_width=80, section="a")
-        floater: float = Field(None, column_width=70, aui_sig_fig=3, section="b")
+        floater: float = Field(
+            None, column_width=70, global_decimal_places=3, section="b"
+        )
 
     class TestDataFrame(BaseModel):
         """a description of TestDataFrame"""
@@ -669,17 +633,9 @@ if __name__ == "__main__":
 
 
 if __name__ == "__main__":
-    # Test: Using AutoObjectFiltered
-    editgrid = EditGrid(
-        schema=TestDataFrame,
-        description=description,
-        ui_add=AutoObjectFiltered,
-        ui_edit=AutoObjectFiltered,
-        warn_on_delete=True,
-    )
-    editgrid.observe(lambda c: print("_value changed"), "_value")
-    editgrid.transposed = True
-    display(editgrid)
+    editgrid.grid.order = ("floater", "string")
+    # ^ NOTE: this will result in a value change in the grid
+
 
 if __name__ == "__main__":
     from ipyautoui.demo_schemas import CoreIpywidgets
